<?php

namespace AppBundle\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\Extension\Core\Type\IntegerType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use AppBundle\Repository\DraftRepository;
use AppBundle\Repository\NationaliteRepository;
use AppBundle\Repository\PaysRepository;
use AppBundle\Repository\TranscoTailleRepository;
use AppBundle\Repository\TranscoPotentielRepository;
use AppBundle\Repository\TranscoPositionRepository;
use AppBundle\Repository\TranscoCaracRepository;
use Doctrine\ORM\EntityManager;

class JoueurNtScoutSearchType extends AbstractType
{
    private $em;

    public function __construct(EntityManager $em)
    {
        $this->em = $em;
    }
    
    public function buildForm(FormBuilderInterface $builder, array $options)
    {   
        $forSale = $options['attr']['forSale'];
        $forSaleByManager = $options['attr']['forSaleByManager'];
        $nationalTeam = $options['attr']['nationalTeam'];
        $showSkills = $options['attr']['showSkills'];
        
        $builder
            ->add(
                    'nationalite',
                    EntityType::class,
                    array(
                        'class'=>'AppBundle:Nationalite',
                        'choice_label'=>'libelle',
                        'required' => true,
                        'mapped' => false,
                        'query_builder' => function(NationaliteRepository $n) {
                            return $n->getAllNationalite();
                            }
                        )
                    )
            ->add(
                    'pays',
                    EntityType::class,
                    array(
                        'class'=>'AppBundle:Pays',
                        'choice_label'=>'nom',
                        'required' => false,
                        'mapped' => false,
                        'query_builder' => function(PaysRepository $p) {
                            return $p->getAllPays();
                            }
                        )
                    )                
            ->add(
                    'nom',
                    TextType::class,
                    array(
                        'required' => false
                        )
                    )
            ->add(
                    'prenom',
                    TextType::class,
                    array(
                        'required' => false
                        )
                    )    
            ->add(
                    'ownerBbId',
                    TextType::class,
                    array(
                        'required' => false
                        )
                    ) 
             ->add(
                    'teamIdDraft',
                    TextType::class,
                    array(
                        'required' => false
                        )
                    )                    
            ->add(
                    'ageMin',
                    IntegerType::class,
                    array(
                        'required' => false,
                        'mapped' => false
                        )
                    )   
            ->add(
                    'ageMax',
                    IntegerType::class,
                    array(
                        'required' => false,
                        'mapped' => false
                        )
                    )
            ->add(
                    'salaireMin',
                    IntegerType::class,
                    array(
                        'required' => false,
                        'mapped' => false
                        )
                    )   
            ->add(
                    'salaireMax',
                    IntegerType::class,
                    array(
                        'required' => false,
                        'mapped' => false
                        )
                    )
             ->add(
                    'potentielMin',
                    EntityType::class,
                    array(
                        'class'=>'AppBundle:TranscoPotentiel',
                        'required' => false,
                        'mapped' => false,
                        'query_builder' => function(TranscoPotentielRepository $tpot) {
                            return $tpot->getAllPotentiel();
                            }
                        )
                    ) 
            ->add(
                    'potentielMax',
                    EntityType::class,
                    array(
                        'class'=>'AppBundle:TranscoPotentiel',
                        'required' => false,
                        'mapped' => false,
                        'query_builder' => function(TranscoPotentielRepository $tpot) {
                            return $tpot->getAllPotentiel();
                            }
                        )
                    )   
            ->add(
                    'tailleMin',
                    EntityType::class,
                    array(
                        'class'=>'AppBundle:TranscoTaille',
                        'required' => false,
                        'mapped' => false,
                        'query_builder' => function(TranscoTailleRepository $ttai) {
                            return $ttai->getAllTaille();
                            }
                        )
                    ) 
            ->add(
                    'tailleMax',
                    EntityType::class,
                    array(
                        'class'=>'AppBundle:TranscoTaille',
                        'required' => false,
                        'mapped' => false,
                        'query_builder' => function(TranscoTailleRepository $ttai) {
                            return $ttai->getAllTaille();
                            }
                        )
                    ) 
            ->add(
                    'position',
                    EntityType::class,
                    array(
                        'class'=>'AppBundle:TranscoPosition',
                        'required' => false,
                        'mapped' => false,
                        'multiple' => true,
                        'query_builder' => function(TranscoPositionRepository $tpos) {
                            return $tpos->getAllPosition();
                            }
                        )
                    ) 
            ->add(
                    'dmiMin',
                    IntegerType::class,
                    array(
                        'required' => false,
                        'mapped' => false
                        )
                    )   
            ->add(
                    'dmiMax',
                    IntegerType::class,
                    array(
                        'required' => false,
                        'mapped' => false
                        )
                    )  
            ->add(
                    'blessure',
                    ChoiceType::class,
                    array(
                        'choices' => array(
                            'Yes' => '1',
                            'No' => '0'
                            ),
                        'required' => false
                        )
                    )
            ->add(
                    'formeMin',
                    EntityType::class,
                    array(
                        'class'=>'AppBundle:TranscoCarac',
                        'required' => false,
                        'mapped' => false,
                        'query_builder' => function(TranscoCaracRepository $tcar) {
                            return $tcar->getCaracForme();
                            }
                        )
                    ) 
            ->add(
                    'formeMax',
                    EntityType::class,
                    array(
                        'class'=>'AppBundle:TranscoCarac',
                        'required' => false,
                        'mapped' => false,
                        'query_builder' => function(TranscoCaracRepository $tcar) {
                            return $tcar->getCaracForme();
                            }
                        )
                    )
        ;

         $arrayRequeteCustom = array(
            'Worlds All-time great' => '1',
        );
        
        if($forSale == 'on')
        {
            $builder
                ->add(
                        'aVendre',
                        ChoiceType::class,
                        array(
                            'choices' => array(
                                'No' => '0',
                                'Yes' => '1'
                                ),
                            'required' => false,
                            )
                        )
            ;
            
            $arrayRequeteCustom["Worlds for sale"] = 2;
        }
        
        if($forSaleByManager == 'on')
        {
            $builder
                ->add(
                        'aVendreByManager',
                        ChoiceType::class,
                        array(
                            'choices' => array(
                                'No' => '0',
                                'Yes' => '1'
                                ),
                            'required' => false,
                            )
                        )
            ;
            $arrayRequeteCustom["Worlds for sale by manager"] = 7;
        }
                
        if($showSkills == 'on')
        {
            $builder
                ->add(
                        'caracConnues',
                        ChoiceType::class,
                        array(
                            'choices' => array(
                                'No' => '0',
                                'Yes' => '1'
                                ),
                            'required' => false,
                            'mapped' => false,
                            )
                        )
            ;
            
            $arrayRequeteCustom["Worlds known skills"] = 3;
        }
        
        $arrayRequeteCustom["Worlds botification soon"] = 4;
        
        if($nationalTeam == 'on')
        {
            $arrayRequeteCustom["Worlds A"] = 5;
            $arrayRequeteCustom["Worlds U21"] = 6;
        
            $builder
                ->add(
                        'equipeNationale',
                        ChoiceType::class,
                        array(
                            'choices' => array(
                                'A' => 'A',
                                'U21' => 'U21'
                                ),
                            'required' => false,
                            'mapped' => false,
                            )
                        )
            ;
        }

        $builder
                ->add(
                        'botBientot',
                        ChoiceType::class,
                        array(
                            'choices' => array(
                                'No' => '0',
                                'Yes' => '1'
                                ),
                            'required' => false,
                            'mapped' => false,
                            )
                        )
                ->add(
                        'requeteCustom',
                        ChoiceType::class,
                        array(
                            'choices' => $arrayRequeteCustom,
                            'required' => false,
                            'mapped' => false,
                            )
                        )
                ->add(
                    'draftId',
                    EntityType::class,
                    array(
                        'class'=>'AppBundle:Draft',
                        'choice_label'=>'libelle',
                        'required' => false,
                        'query_builder' => function(DraftRepository $r) {
                            return $r->getDraftSortDesc();
                            }
                        )
                    )
                ->add(
                    'Recherche',
                    SubmitType::class
                    )
        ;
    }
}