<?php

namespace AppBundle\Repository;

use AppBundle\Entity\Account;
use AppBundle\Entity\Roster;

use Doctrine\ORM\EntityRepository;

class AccountRepository extends EntityRepository
{
    public function updateOption($user,$optionName,$afficheOption)
    {
        $em = $this->getEntityManager();
        $infoUser = $em->getRepository('AppBundle:Account')->infoAccount($user);
        $monAccount = $em->getRepository('AppBundle:Account')->find($infoUser->getId());
        switch($optionName)
        {
            case 'divMyRosters' :
                    $monAccount->setRoster($afficheOption);
                break;
            case 'divMySharedRosters' :
                    $monAccount->setRosterPartage($afficheOption);
                break;
            case 'divMySimulations' :
                    $monAccount->setSimulation($afficheOption);
                break;
            case 'divMyAnalysis' :
                    $monAccount->setAnalyse($afficheOption);
                break;
        }
        
        $em->persist($monAccount);
        $em->flush();
    }
    
    public function erreurConnexion($session)
    {
        $em = $this->getEntityManager();
        $account = $em->getRepository('AppBundle:Configuration')->findOneBy(
            array(
                'idParam'=>'account',
            ));
        $accountVal = $account->getValParam();
        
        if(is_object($session))
        {
            $session->remove('messageAccountError');
            $session->remove('messageAccountSuccess');
            $messageAccount = $session->get('messageAccount');
            $session->remove('messageAccount');
        }
        else
        {
            $messageAccount = 'Error Connexion';
        }
        
        $tabRetour['page'] = 'joueurntscout/accountLogin.html.twig';
        $tabRetour['param'] = array(
            'accountActif' => $accountVal,
            'messageAccount' => $messageAccount,
          );

        return $tabRetour;
    }
    
    
    public function create($login,$password)
    {
        $em = $this->getEntityManager();
        
        if($login == '' || $password == '')
        {
            $retour = 'Login/Password required';
        }
        else
        {
            $unAccount = $em->getRepository('AppBundle:Account')->findOneByLogin($login);
            if($unAccount)
            {
                $retour = 'Login already existing';
            }
            else
            {
                $findme   = ' ';
                $pos = strpos($login, $findme);
                if ($pos === false) 
                {
                    $retour = 'Account created';
                    $unAccount = new Account();
                    $unAccount->setLogin($login);
                    $unAccount->setPassword($password);
                    $dateCreation = new \DateTime();
                    $unAccount->setDateCreation($dateCreation);
                    $unAccount->setDateDerniereConnexion($dateCreation);

                    $em->persist($unAccount);
                    $em->flush();
                } 
                else 
                {
                    $retour = 'The login must not contain spaces';
                }
            }
        }
        return $retour;
    }
    
    public function login($login,$password)
    {
        $em = $this->getEntityManager();

        if($login == '' || $password == '')
        {
            $retour = 'Login/Password required';
        }
        else
        {
            $unAccount = $em->getRepository('AppBundle:Account')->findOneBy(
                    array(
                        'login' => $login,
                        'password' => $password,
                    )
                );
            
            if($unAccount)
            {
                $dateConnexion = new \DateTime();
                $unAccount->setDateDerniereConnexion($dateConnexion);
                $em->persist($unAccount);
                $em->flush();
                
                $retour = 'OK';
            }
            else
            {
                $retour = 'Unknown account';
            }
        }
      
        return $retour;
    }
    
    public function logout($tokenStorage)
    {
       $tokenStorage->setToken(NULL);
       return $tokenStorage;
    }
    
    public function connexionOk($user)
    {
        $retour = "oui";
        if($user == 'anon.' || $user == '')
        {
            $retour = "non";
        }
        
        return $retour;
    }
    
    public function infoAccount($user)
    {
        $em = $this->getEntityManager();
        $unAccount = $unAccount = $em->getRepository('AppBundle:Account')->findOneByLogin($user);
        if($unAccount)
        {
            $retour = $unAccount;
        }
        else
        {
            $retour = "Unknown account";
        }
        return $retour;
    }
    
    public function loadLinkNtso($linkNtso,$nomChoisi,$user,$session)
    {
        $em = $this->getEntityManager();
        $unRoster = $em->getRepository('AppBundle:Roster')->findOneByClefNtso($linkNtso);
        if($unRoster)
        {
            $idRosterOrigine = $unRoster->getId();
            $typeDuplique = 'loadKey';
            $retour = $this->dupliqueRoster($nomChoisi,$idRosterOrigine,$user,$session,$typeDuplique);
            if($retour == 'ok')
            {
                $session->set('messageAccountSuccess','NTSO Key loaded !'); 
            }
            else
            {
                $session->set('messageAccountError','NTSO Key not load !'); 
            }
        }
        else
        {
            $session->set('messageAccountError','Invalid NTSO Key !'); 
        }
    }
    
    public function loadPlayerNtso($bbId,$user,$session)
    {
        $em = $this->getEntityManager();
        $unJoueur = $em->getRepository('AppBundle:JoueurNtScout')->findByBbId($bbId);
        if($unJoueur)
        {
            $session->set('messageAccountSuccess','NTSO Player loaded !');
            $idRoster = $session->get('idRoster');
            $account = $this->infoAccount($user);
            $em->getRepository('AppBundle:AccountJoueur')->create($account->getId(),$bbId,$idRoster);
        }
        else
        {
            $session->set('messageAccountError','Invalid NTSO Player !'); 
        }
    }
    
    public function createRoster($nomChoisi,$user,$session)
    {
        $em = $this->getEntityManager();
        
        $infoUser = $this->infoAccount($user);

        $nomFinal = substr($nomChoisi, 0, 50);
        $clefNtso = sha1(time().rand());
        
        $unRoster = $em->getRepository('AppBundle:Roster')->findOneBy(
            array(
                'nom'=>$nomChoisi,
                'idAccount'=>$infoUser->getId(),
            ));
        
        if($unRoster)
        {
            $messageError = 'Roster Name already existing';
            $session->set('messageAccountError',$messageError);
            $unRoster = 'null';
        }
        else
        {
            $unRoster = new Roster();
            $unRoster->setIdAccount($infoUser->getId());
            $unRoster->setNom($nomFinal);
            $unRoster->setClefNtso($clefNtso);
            $dateCreation = new \DateTime();
            $unRoster->setDateCreation($dateCreation);
            $em->persist($unRoster);
            $em->flush();
        }
        
        return $unRoster;
    }
    
    public function dupliqueRoster($nomChoisi,$idRosterOrigine,$user,$session,$typeDuplique)
    {
        $em = $this->getEntityManager();
        
        $infoUser = $this->infoAccount($user);
        $idAccount = $infoUser->getId();
        
        if($typeDuplique == 'loadKey')
        {
            $rosterOrigine = $em->getRepository('AppBundle:Roster')->findOneBy(
                array(
                    'id'=>$idRosterOrigine,
                ));
        }
        else
        {
            $rosterOrigine = $em->getRepository('AppBundle:Roster')->findOneBy(
                array(
                    'id'=>$idRosterOrigine,
                    'idAccount'=>$idAccount,
                ));
        }
        $retour = 'ok';
        if($rosterOrigine)
        {
            $rosterCopie = $this->createRoster($nomChoisi,$user,$session);
            
            if($rosterCopie <> 'null')
            {
                $idRosterCopie = $rosterCopie->getId();

                if($typeDuplique == 'loadKey')
                {
                    $tabAccountJoueur = $em->getRepository('AppBundle:AccountJoueur')->findBy(
                        array(
                            'idRoster'=>$idRosterOrigine,
                        )); 
                }
                else
                {
                    $tabAccountJoueur = $em->getRepository('AppBundle:AccountJoueur')->findBy(
                        array(
                            'idRoster'=>$idRosterOrigine,
                            'idAccount'=>$idAccount,
                        )); 
                }
                foreach($tabAccountJoueur as $unAccountJoueur)
                {
                    $bbId = $unAccountJoueur->getBbId();
                    $em->getRepository('AppBundle:AccountJoueur')->create($idAccount,$bbId,$idRosterCopie);
                }

                if($typeDuplique == 'loadKey')
                {
                    $tabAccountJoueurCarac = $em->getRepository('AppBundle:AccountJoueurCarac')->findBy(
                        array(
                            'idRoster'=>$idRosterOrigine,
                        )); 
                }
                else
                {
                    $tabAccountJoueurCarac = $em->getRepository('AppBundle:AccountJoueurCarac')->findBy(
                    array(
                        'idRoster'=>$idRosterOrigine,
                        'idAccount'=>$idAccount,
                    )); 
                }
                foreach($tabAccountJoueurCarac as $unAccountJoueurCarac)
                {
                    $bbId = $unAccountJoueurCarac->getBbId();
                    $js = $unAccountJoueurCarac->getJs();
                    $ps = $unAccountJoueurCarac->getPs();
                    $de = $unAccountJoueurCarac->getDe();
                    $agi = $unAccountJoueurCarac->getAgi();
                    $dri = $unAccountJoueurCarac->getDri();
                    $pa = $unAccountJoueurCarac->getPa();
                    $si = $unAccountJoueurCarac->getSi();
                    $di = $unAccountJoueurCarac->getDi();
                    $reb = $unAccountJoueurCarac->getReb();
                    $co = $unAccountJoueurCarac->getCo();
                    $end = $unAccountJoueurCarac->getEnd();
                    $lf = $unAccountJoueurCarac->getLf();
                    $exp = $unAccountJoueurCarac->getExp();

                    $chaineCarac = $js."_".$ps."_".$de."_".$agi."_".$dri."_".$pa."_".$si."_".$di."_".$reb."_".$co."_".$end."_".$lf."_".$exp;
                    $em->getRepository('AppBundle:AccountJoueurCarac')->update($user,$bbId,$chaineCarac,$idRosterCopie);
                    
                    $commentaire = $unAccountJoueurCarac->getCommentaire();
                    $em->getRepository('AppBundle:AccountJoueurCarac')->updateCommentaire($user,$bbId,$commentaire,$idRosterCopie);
                }
                if($typeDuplique == 'loadKey')
                {
                    $tabAccountJoueurPosition = $em->getRepository('AppBundle:AccountJoueurPosition')->findBy(
                        array(
                            'idRoster'=>$idRosterOrigine,
                        )); 
                }
                else
                {
                    $tabAccountJoueurPosition = $em->getRepository('AppBundle:AccountJoueurPosition')->findBy(
                        array(
                            'idRoster'=>$idRosterOrigine,
                            'idAccount'=>$idAccount,
                        )); 
                }
                foreach($tabAccountJoueurPosition as $unAccountJoueurPosition)
                {
                    $bbId = $unAccountJoueurPosition->getBbId();
                    $position = $unAccountJoueurPosition->getPosition();
                    $em->getRepository('AppBundle:Roster')->addPersoToRoster($bbId,$position,$idRosterCopie,$user);
                }
            }
            else
            {
                $retour = 'ko';
            }
        }
        else
        {
            $retour = 'ko';
        }
        
        return $retour;
    }
}