<?php

namespace AppBundle\Repository;

use Doctrine\ORM\EntityRepository;

class RechercheRepository extends EntityRepository
{
    public function countRecherche($dateDernierLancement)
    {        
        $format = 'd/m/Y H:i:s';
        $date = \DateTime::createFromFormat($format, $dateDernierLancement);

        $em = $this->getEntityManager();
        $requete = 'SELECT COUNT(1) as nbRecherche FROM AppBundle:Recherche r WHERE r.dateRecherche >= :dateDernierLancement';
        $query = $em->createQuery($requete);
        $query->setParameter('dateDernierLancement', $date);
        $count = $query->getResult();
        return $count[0];
    }
    
    public function randomStat()
    {        
        $valeurMin = 1;
        $valeurMax = 7;
        $stat = mt_rand($valeurMin,$valeurMax);

        $em = $this->getEntityManager();
        $requete = 'SELECT r.criteresNoms, r.criteresValeurs FROM AppBundle:Recherche r';
        $query = $em->createQuery($requete);
        $tabRecherche = $query->getResult();

        $tab = array();
        foreach($tabRecherche as $uneRecherche)
        {
            $tabCriteresNoms = explode(',',$uneRecherche['criteresNoms']);
            $tabCriteresValeurs = explode(',',$uneRecherche['criteresValeurs']);
            switch($stat)
            {
                case 1:
                    $key = array_search('nationalite', $tabCriteresNoms);
                    $tab[] = $tabCriteresValeurs[$key];
                    break;
                case 2:
                    $key = array_search('position', $tabCriteresNoms);
                    $tabAvantTraitement = explode('_',$tabCriteresValeurs[$key]);                    
                    if(count($tabAvantTraitement) > 1)
                    {
                        foreach($tabAvantTraitement as $uneValeur)
                        {
                            $tab[] = $uneValeur;
                        }
                    }
                    else
                    {
                        $tab[] = $tabCriteresValeurs[$key];
                    }                  
                    break;
                case 3:
                    $keyMin = array_search('potentielMin', $tabCriteresNoms);
                    $keyMax = array_search('potentielMax', $tabCriteresNoms);
                    $tab[] = $tabCriteresValeurs[$keyMin];
                    $tab[] = $tabCriteresValeurs[$keyMax];
                    break;
                case 4:
                    $keyMin = array_search('ageMin', $tabCriteresNoms);
                    $keyMax = array_search('ageMax', $tabCriteresNoms);
                    $tab[] = $tabCriteresValeurs[$keyMin];
                    $tab[] = $tabCriteresValeurs[$keyMax];
                    break;
                case 5:
                    $keyMin = array_search('tailleMin', $tabCriteresNoms);
                    $keyMax = array_search('tailleMax', $tabCriteresNoms);
                    $tab[] = $tabCriteresValeurs[$keyMin];
                    $tab[] = $tabCriteresValeurs[$keyMax];
                    break;
                case 6:
                    $key = array_search('equipeNationale', $tabCriteresNoms);
                    $tab[] = $tabCriteresValeurs[$key];
                    break;
                case 7:
                    $key = array_search('paysLancement', $tabCriteresNoms);
                    if($key <> null)
                    {
                        $tab[] = $tabCriteresValeurs[$key];
                    }
                    break;
            }
        }
       
        /*
        echo "<pre>";
        print_r($tab);
        echo "</pre>";
        */
        
        $tabCount = array_count_values($tab);
        unset($tabCount['']);
        
        /*
        echo "<pre>";
        print_r($tabCount);
        echo "</pre>";
        echo max($tabCount);
        die();
        */
        
        $description = 'No search statistics available';
        $valeur = '';
        if($tabCount)
        {
            $nbCount = max($tabCount);
            $idMax = array_search( $nbCount, $tabCount);

            switch($stat)
            {
                case 1:
                    $objNationalite = $em->getRepository('AppBundle:Nationalite')->find($idMax);
                    $description = "Most searched nationality";
                    $valeur = $objNationalite;
                    break;
                case 2:
                    $objPosition = $em->getRepository('AppBundle:TranscoPosition')->find($idMax);
                    $description = "Most searched position";
                    $valeur = $objPosition;    
                    break;
                case 3:
                    $objPotentiel = $em->getRepository('AppBundle:TranscoPotentiel')->find($idMax);
                    $description = "Most searched potential";
                    $valeur = $objPotentiel;    
                    break;
                case 4:
                    $description = "Most searched age";
                    $valeur = $idMax;    
                    break;
                case 5:
                    $objTaille = $em->getRepository('AppBundle:TranscoTaille')->find($idMax);
                    $description = "Most searched height";
                    $valeur = $objTaille;    
                    break;
                case 6:
                    $description = "Most searched national team";
                    $valeur = $idMax;    
                    break;
                case 7:
                    $objPaysLancement = $em->getRepository('AppBundle:Nationalite')->findOneBy(array('codePaysIso'=>$idMax));
                    $description = "Nationality using NTSO most often";
                    $valeur = $objPaysLancement;    
                    break;
            }
        }
        
        $tabRetour = array();
        $tabRetour['description'] = $description;
        $tabRetour['valeur'] = $valeur;
        if($valeur <> '')
        {   
            $tabRetour['valeur'] .= " (".$nbCount." times)";
        }

        return $tabRetour;
    }
}